@@ -1,7 +1,7 @@
 package Complete::Bash;
 
-our $DATE = '2019-06-27'; # DATE
-our $VERSION = '0.323'; # VERSION
+our $DATE = '2019-06-28'; # DATE
+our $VERSION = '0.324'; # VERSION
 
 use 5.010001;
 use strict;
@@ -681,7 +681,7 @@ sub format_completion {
             }
             if (length $summary) {
                 $res[$_] = sprintf(
-                    "%-${max_entry_width}s  %".
+                    "%-${max_entry_width}s |%".
                         ($summary_align eq 'right' ? $max_summ_width : '')."s",
                     $res[$_], $summary);
             }
@@ -723,7 +723,7 @@ Complete::Bash - Completion routines for bash shell
 
 =head1 VERSION
 
-This document describes version 0.323 of Complete::Bash (from Perl distribution Complete-Bash), released on 2019-06-27.
+This document describes version 0.324 of Complete::Bash (from Perl distribution Complete-Bash), released on 2019-06-28.
 
 =head1 DESCRIPTION
 
